@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef BACKUPJOB_H
 #define BACKUPJOB_H
@@ -22,7 +22,8 @@ public:
 	enum ErrorCodes {
 		ErrorWithLog = UserDefinedError,
 		ErrorWithoutLog,
-		ErrorSuggestRepair
+		ErrorSuggestRepair,
+		ErrorSourcesConfig
 	};
 
 	void start() override;
