@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef BUPJOB_H
 #define BUPJOB_H
@@ -9,6 +9,7 @@
 
 #include <KProcess>
 #include <QElapsedTimer>
+#include <QRegularExpression>
 
 class KupDaemon;
 
@@ -23,6 +24,7 @@ protected slots:
 	void performJob() override;
 	void slotCheckingStarted();
 	void slotCheckingDone(int pExitCode, QProcess::ExitStatus pExitStatus);
+	void startIndexing();
 	void slotIndexingStarted();
 	void slotIndexingDone(int pExitCode, QProcess::ExitStatus pExitStatus);
 	void slotSavingStarted();
@@ -42,6 +44,12 @@ protected:
 	QElapsedTimer mInfoRateLimiter;
 	int mHarmlessErrorCount;
 	bool mAllErrorsHarmless;
+	QRegularExpression mLineBreaksRegExp;
+	QRegularExpression mNonsenseRegExp;
+	QRegularExpression mFileGoneRegExp;
+	QRegularExpression mProgressRegExp;
+	QRegularExpression mErrorCountRegExp;
+	QRegularExpression mFileInfoRegExp;
 };
 
 #endif /*BUPJOB_H*/
