@@ -1,28 +1,14 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "bupverificationjob.h"
 
+#include <QThread>
+
 #include <KLocalizedString>
 
-BupVerificationJob::BupVerificationJob(const BackupPlan &pBackupPlan, const QString &pDestinationPath,
+BupVerificationJob::BupVerificationJob(BackupPlan &pBackupPlan, const QString &pDestinationPath,
                                        const QString &pLogFilePath, KupDaemon *pKupDaemon)
    : BackupJob(pBackupPlan, pDestinationPath, pLogFilePath, pKupDaemon){
 	mFsckProcess.setOutputChannelMode(KProcess::SeparateChannels);
@@ -46,6 +32,7 @@ void BupVerificationJob::performJob() {
 	mFsckProcess << QStringLiteral("bup");
 	mFsckProcess << QStringLiteral("-d") << mDestinationPath;
 	mFsckProcess << QStringLiteral("fsck") << QStringLiteral("--quick");
+	mFsckProcess << QStringLiteral("-j") << QString::number(qMin(4, QThread::idealThreadCount()));
 
 	connect(&mFsckProcess, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(slotCheckingDone(int,QProcess::ExitStatus)));
 	connect(&mFsckProcess, SIGNAL(started()), SLOT(slotCheckingStarted()));
@@ -58,10 +45,14 @@ void BupVerificationJob::slotCheckingStarted() {
 }
 
 void BupVerificationJob::slotCheckingDone(int pExitCode, QProcess::ExitStatus pExitStatus) {
-	mLogStream << QString::fromUtf8(mFsckProcess.readAllStandardError());
+	QString lErrors = QString::fromUtf8(mFsckProcess.readAllStandardError());
+	if(!lErrors.isEmpty()) {
+		mLogStream << lErrors << endl;
+	}
+	mLogStream << "Exit code: " << pExitCode << endl;
 	if(pExitStatus != QProcess::NormalExit) {
-		mLogStream << endl << QStringLiteral("Integrity check failed (the process crashed). Your backups could be "
-		                                    "corrupted! See above for details.") << endl;
+		mLogStream << QStringLiteral("Integrity check failed (the process crashed). Your backups could be "
+		                             "corrupted! See above for details.") << endl;
 		if(mBackupPlan.mGenerateRecoveryInfo) {
 			jobFinishedError(ErrorSuggestRepair, xi18nc("@info notification",
 			                                    "Failed backup integrity check. Your backups could be corrupted! "
@@ -71,13 +62,13 @@ void BupVerificationJob::slotCheckingDone(int pExitCode, QProcess::ExitStatus pE
 			                                                            "See log file for more details."));
 		}
 	} else if(pExitCode == 0) {
-		mLogStream << endl << QStringLiteral("Backup integrity test was successful. "
-		                                     "Your backups are fine. See above for details.") << endl;
-		jobFinishedError(ErrorWithLog, xi18nc("@info notification", "Backup integrity test was successful, "
+		mLogStream << QStringLiteral("Backup integrity test was successful. "
+		                             "Your backups are fine. See above for details.") << endl;
+		jobFinishedError(ErrorWithLog, xi18nc("@info notification", "Backup integrity test was successful. "
 		                                                            "Your backups are fine."));
 	} else {
-		mLogStream << endl << QStringLiteral("Integrity check failed. Your backups are "
-		                                     "corrupted! See above for details.") << endl;
+		mLogStream << QStringLiteral("Integrity check failed. Your backups are "
+		                             "corrupted! See above for details.") << endl;
 		if(mBackupPlan.mGenerateRecoveryInfo) {
 			jobFinishedError(ErrorSuggestRepair, xi18nc("@info notification",
 			                                            "Failed backup integrity check. Your backups are corrupted! "
