@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef EDEXECUTOR_H
 #define EDEXECUTOR_H
@@ -12,8 +12,6 @@
 
 class BackupPlan;
 
-class KJob;
-
 // Plan executor that stores the backup to an external disk.
 // Uses libsolid to monitor for when it becomes available.
 class EDExecutor: public PlanExecutor
@@ -26,20 +24,21 @@ public:
 public slots:
 	void checkStatus() override;
 	void showBackupFiles() override;
+	void showBackupPurger() override;
 
 protected slots:
 	void deviceAdded(const QString &pUdi);
 	void deviceRemoved(const QString &pUdi);
 	void updateAccessibility();
 	void startBackup() override;
-	void slotBackupDone(KJob *pJob);
-	void slotBackupSizeDone(KJob *pJob);
 
 protected:
+	bool ensureAccessible(bool &pReturnLater);
 	Solid::StorageAccess *mStorageAccess;
 	QString mCurrentUdi;
 	bool mWantsToRunBackup;
 	bool mWantsToShowFiles;
+	bool mWantsToPurge;
 };
 
 #endif // EDEXECUTOR_H
