@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "kupdaemon.h"
 #include "kupsettings.h"
@@ -209,6 +209,10 @@ void KupDaemon::handleRequests(QLocalSocket *pSocket) {
 		sendStatus(pSocket);
 		return;
 	}
+	if(lOperation == QStringLiteral("reload")) {
+		reloadConfig();
+		return;
+	}
 
 	int lPlanNumber = lCommand["plan number"].toInt(-1);
 	if(lPlanNumber < 0 || lPlanNumber >= mExecutors.count()) {
@@ -217,6 +221,9 @@ void KupDaemon::handleRequests(QLocalSocket *pSocket) {
 	if(lOperation == QStringLiteral("save backup")) {
 		mExecutors.at(lPlanNumber)->startBackupSaveJob();
 	}
+	if(lOperation == QStringLiteral("remove backups")) {
+		mExecutors.at(lPlanNumber)->showBackupPurger();
+	}
 	if(lOperation == QStringLiteral("show log file")) {
 		mExecutors.at(lPlanNumber)->showLog();
 	}
@@ -303,6 +310,7 @@ void KupDaemon::sendStatus(QLocalSocket *pSocket) {
 		lPlan[QStringLiteral("icon name")] = BackupPlan::iconName(lExecutor->mPlan->backupStatus());
 		lPlan[QStringLiteral("log file exists")] = QFileInfo::exists(lExecutor->mLogFilePath);
 		lPlan[QStringLiteral("busy")] = lExecutor->busy();
+		lPlan[QStringLiteral("bup type")] = lExecutor->mPlan->mBackupType == BackupPlan::BupType;
 		lPlans.append(lPlan);
 	}
 	lStatus["plans"] = lPlans;
