@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "kupservice.h"
 #include "kupjob.h"
@@ -17,3 +17,12 @@ ServiceJob *KupService::createJob(const QString &pOperation, QMap<QString, QVari
 	return new KupJob(mPlanNumber, mSocket, pOperation, pParameters, this);
 }
 
+KupDaemonService::KupDaemonService(QLocalSocket *pSocket, QObject *pParent)
+   : Plasma::Service(pParent), mSocket(pSocket)
+{
+	setName(QStringLiteral("kupdaemonservice"));
+}
+
+ServiceJob *KupDaemonService::createJob(const QString &pOperation, QMap<QString, QVariant> &pParameters) {
+	return new KupJob(-1, mSocket, pOperation, pParameters, this);
+}
