@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "filedigger.h"
 #include "mergedvfsmodel.h"
@@ -38,7 +38,7 @@ FileDigger::FileDigger(QString pRepoPath, QString pBranchName, QWidget *pParent)
 }
 
 QSize FileDigger::sizeHint() const {
-    return QSize(800, 600);
+    return {800, 600};
 }
 
 void FileDigger::updateVersionModel(const QModelIndex &pCurrent, const QModelIndex &pPrevious) {
