@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "filedigger.h"
 #include "mergedvfs.h"
@@ -13,6 +13,7 @@
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
+#include <QDir>
 #include <QFile>
 #include <QTextStream>
 
@@ -22,7 +23,7 @@ int main(int pArgCount, char **pArgArray) {
 
 	KLocalizedString::setApplicationDomain("kup");
 
-	KAboutData lAbout(QStringLiteral("kupfiledigger"), xi18nc("@title", "File Digger"), QStringLiteral("0.7.3"),
+	KAboutData lAbout(QStringLiteral("kupfiledigger"), xi18nc("@title", "File Digger"), QStringLiteral("0.9.1"),
 	                  i18n("Browser for bup archives."),
 	                  KAboutLicense::GPL, i18n("Copyright (C) 2013-2020 Simon Persson"));
 	lAbout.addAuthor(i18n("Simon Persson"), i18n("Maintainer"), "simon.persson@mykolab.com");
@@ -42,7 +43,8 @@ int main(int pArgCount, char **pArgArray) {
 	QString lRepoPath;
 	QStringList lPosArgs = lParser.positionalArguments();
 	if(!lPosArgs.isEmpty()) {
-		lRepoPath = lPosArgs.takeFirst();
+		auto lDir = QDir(lPosArgs.takeFirst());
+		lRepoPath = lDir.absolutePath();
 	}
 
 	// This needs to be called first thing, before any other calls to libgit2.
