@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "backupplanwidget.h"
 #include "backupplan.h"
@@ -201,8 +201,6 @@ ConfigIncludeDummy::ConfigIncludeDummy(FolderSelectionModel *pModel, FolderSelec
 {
 	connect(mModel, &FolderSelectionModel::includedPathAdded, this, &ConfigIncludeDummy::includeListChanged);
 	connect(mModel, &FolderSelectionModel::includedPathRemoved, this, &ConfigIncludeDummy::includeListChanged);
-	KConfigDialogManager::changedMap()->insert(QStringLiteral("ConfigIncludeDummy"),
-	                                           SIGNAL(includeListChanged()));
 }
 
 QStringList ConfigIncludeDummy::includeList() {
@@ -226,8 +224,6 @@ ConfigExcludeDummy::ConfigExcludeDummy(FolderSelectionModel *pModel, FolderSelec
 {
 	connect(mModel, &FolderSelectionModel::excludedPathAdded, this, &ConfigExcludeDummy::excludeListChanged);
 	connect(mModel, &FolderSelectionModel::excludedPathRemoved, this, &ConfigExcludeDummy::excludeListChanged);
-	KConfigDialogManager::changedMap()->insert(QStringLiteral("ConfigExcludeDummy"),
-	                                           SIGNAL(excludeListChanged()));
 }
 
 QStringList ConfigExcludeDummy::excludeList() {
@@ -273,8 +269,12 @@ FolderSelectionWidget::FolderSelectionWidget(FolderSelectionModel *pModel, QWidg
 	mTreeView->setAnimated(true);
 	mTreeView->setModel(mModel);
 	mTreeView->setHeaderHidden(true);
-	// always expand the root, prevents problem with empty include&exclude lists.
-	mTreeView->expand(mModel->index(QStringLiteral("/")));
+	// always expand the home folder, prevents problem with empty include&exclude lists.
+	QModelIndex lIndex = mModel->index(QDir::homePath());
+	while(lIndex.isValid()) {
+		mTreeView->expand(lIndex);
+		lIndex = lIndex.parent();
+	}
 
 	auto lIncludeDummy = new ConfigIncludeDummy(mModel, this);
 	lIncludeDummy->setObjectName(QStringLiteral("kcfg_Paths included"));
@@ -466,7 +466,8 @@ BackupPlanWidget::BackupPlanWidget(BackupPlan *pBackupPlan, const QString &pBupV
 
 	mConfigPages = new KPageWidget;
 	mConfigPages->addPage(createTypePage(pBupVersion, pRsyncVersion));
-	mConfigPages->addPage(createSourcePage());
+	mSourcePage = createSourcePage();
+	mConfigPages->addPage(mSourcePage);
 	mConfigPages->addPage(createDestinationPage());
 	mConfigPages->addPage(createSchedulePage());
 	mConfigPages->addPage(createAdvancedPage(pPar2Available));
@@ -488,6 +489,10 @@ void BackupPlanWidget::saveExtraData() {
 	mDriveSelection->saveExtraData();
 }
 
+void BackupPlanWidget::showSourcePage() {
+	mConfigPages->setCurrentPage(mSourcePage);
+}
+
 KPageWidgetItem *BackupPlanWidget::createTypePage(const QString &pBupVersion, const QString &pRsyncVersion) {
 	mVersionedRadio = new QRadioButton;
 	QString lVersionedInfo = xi18nc("@info", "This type of backup is an <emphasis>archive</emphasis>. It contains both "
@@ -874,10 +879,10 @@ KPageWidgetItem *BackupPlanWidget::createAdvancedPage(bool pPar2Available) {
 	});
 	auto lLabelUpdater = [lExcludesLabel](bool pVersioned){
 		QString lHelpUrl = pVersioned ? QStringLiteral("man:///bup-index") : QStringLiteral("man:///rsync");
-		lExcludesLabel->setText(xi18nc("@label:textbox",
+		lExcludesLabel->setText(xi18nc("@info",
 		                               "Patterns need to be listed in a text file with one pattern per line. "
-		                               "Files and folders with names matching any of the patterns will be "
-		                               "excluded from the backup. The pattern format is documented <a href=\"%1\">here</a>.",
+		                               "Files and folders with names that match any of the patterns will be "
+		                               "excluded from the backup. The pattern format is documented <link url='%1'>here</link>.",
 		                               lHelpUrl));
 	};
 	lLabelUpdater(false);
