@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "kupkcm.h"
 #include "backupplan.h"
@@ -28,10 +28,10 @@
 K_PLUGIN_FACTORY(KupKcmFactory, registerPlugin<KupKcm>();)
 
 KupKcm::KupKcm(QWidget *pParent, const QVariantList &pArgs)
-    : KCModule(pParent, pArgs)
+    : KCModule(pParent, pArgs), mSourcePageToShow(0)
 {
 	KAboutData lAbout(QStringLiteral("kcm_kup"), i18n("Kup Configuration Module"),
-	                  QStringLiteral("0.7.3"),
+	                  QStringLiteral("0.9.1"),
 	                  i18n("Configuration of backup plans for the Kup backup system"),
 	                  KAboutLicense::GPL, i18n("Copyright (C) 2011-2020 Simon Persson"));
 	lAbout.addAuthor(i18n("Simon Persson"), i18n("Maintainer"), "simon.persson@mykolab.com");
@@ -95,12 +95,21 @@ KupKcm::KupKcm(QWidget *pParent, const QVariantList &pArgs)
 		mStackedLayout = new QStackedLayout;
 		mStackedLayout->addWidget(mFrontPage);
 		setLayout(mStackedLayout);
+		QListIterator<QVariant> lIter(pArgs);
+		while(lIter.hasNext()) {
+			QVariant lVariant = lIter.next();
+			if(lVariant.type() == QVariant::String) {
+				QString lArgument = lVariant.toString();
+				if(lArgument == QStringLiteral("show_sources") && lIter.hasNext()) {
+					mSourcePageToShow = lIter.next().toString().toInt();
+				}
+			}
+		}
 	}
 }
 
 QSize KupKcm::sizeHint() const {
-	int lBaseWidth = fontMetrics().horizontalAdvance('M');
-	return {lBaseWidth * 65, lBaseWidth * 35};
+	return {800, 600};
 }
 
 void KupKcm::load() {
@@ -123,6 +132,11 @@ void KupKcm::load() {
 	// because user pressed reset button. need to manually reset the "changed" state to false
 	// in this case.
 	unmanagedWidgetChangeState(false);
+	if(mSourcePageToShow > 0) {
+		mStackedLayout->setCurrentIndex(mSourcePageToShow);
+		mPlanWidgets[mSourcePageToShow - 1]->showSourcePage();
+		mSourcePageToShow = 0; //only trigger on first load after startup.
+	}
 }
 
 void KupKcm::save() {
